==> haskell-primitive-extras-0.10.1.10-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-extras
version:              0.10.1.10
visibility:           public
id:                   primitive-extras-0.10.1.10-5BUCZgpFhI6CUKJrh2nZvK
key:                  primitive-extras-0.10.1.10-5BUCZgpFhI6CUKJrh2nZvK
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/metrix-ai/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  a13659f1aeb6f23d915acbd0a8cc0e8a
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.1.10-5BUCZgpFhI6CUKJrh2nZvK
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    deferred-folds-0.9.18.6-GquzRpErrnl11ZQrZBo5e1
    focus-1.0.3.2-EuoDZarCUGl6fLOfy9zX9f
    foldl-1.4.16-1BhYcKLm1507ZwegSL0d1V
    list-t-1.0.5.4-8WXUQUVfTKQLcXUAyBA5X5
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB
    primitive-unlifted-0.1.3.1-GX3vvjUZsgWHuLK3gWSN7A
    profunctors-5.6.2-5vROZbe5UdTK0D0maJHxvc
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-primitive-extras-0.10.1.10-22-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-primitive-extras.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 primitive-extras
version:              0.10.1.10
visibility:           public
id:                   primitive-extras-0.10.1.10-ChrfREhVn8B75nPomtRoZW
key:                  primitive-extras-0.10.1.10-ChrfREhVn8B75nPomtRoZW
license:              MIT
copyright:            (c) 2018, Metrix.AI
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/metrix-ai/primitive-extras
synopsis:             Extras for the "primitive" library
description:
    Raw collection of extra utiltilies for the "primitive" library.

category:             Primitive
abi:                  fe5c6237a12eea5f35ad50ca9a499568
exposed:              True
exposed-modules:
    PrimitiveExtras.Bitmap PrimitiveExtras.By6Bits
    PrimitiveExtras.PrimArray PrimitiveExtras.PrimMultiArray
    PrimitiveExtras.SmallArray PrimitiveExtras.UnliftedArray

hidden-modules:
    PrimitiveExtras.FoldMs PrimitiveExtras.Folds
    PrimitiveExtras.Prelude PrimitiveExtras.Types

import-dirs:          /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
library-dirs:         /usr/lib/ghc-9.2.8/site-local/primitive-extras-0.10.1.10
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-primitive-extras
hs-libraries:         HSprimitive-extras-0.10.1.10-ChrfREhVn8B75nPomtRoZW
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    cereal-0.5.8.3-9zcITCTkqXtHoa6jbeSF22
    deferred-folds-0.9.18.6-KHEeDp9XIhIIGRw8gzAHPk
    focus-1.0.3.2-AWFlVRsdsCe4vhU1VxYkfr
    foldl-1.4.16-EG9jDJYKDs3HBMfEyOGPwq
    list-t-1.0.5.4-9XruqXOdsOd7UWvIvkXinW
    primitive-0.7.4.0-IuAkHfsD4drDvErljoigXB
    primitive-unlifted-0.1.3.1-GX3vvjUZsgWHuLK3gWSN7A
    profunctors-5.6.2-GpDaCOOY8ar8rCckMV8A0H
    vector-0.13.1.0-FuSYSqJEiCU51oStZmHlCe

haddock-interfaces:
    /usr/share/doc/haskell-primitive-extras/html/primitive-extras.haddock

haddock-html:         /usr/share/doc/haskell-primitive-extras/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
